@@ -1,7 +1,7 @@
+pub mod camera;
 pub mod color;
 pub mod model;
-pub mod shader_program;
-pub mod sprite_sheet;
-pub mod texture;
+pub mod render_data;
 pub mod renderer;
-pub mod buffers;
\ No newline at end of file
+pub mod texture;
+pub mod vertex;
